@@ -2,11 +2,9 @@ use strict;
 use warnings;
 
 package WebService::Geocodio::Request;
-{
-  $WebService::Geocodio::Request::VERSION = '0.04';
-}
-
+$WebService::Geocodio::Request::VERSION = '0.05';
 use Moo::Role;
+use strictures 2;
 use HTTP::Tiny;
 use Carp qw(confess);
 use WebService::Geocodio::Location;
@@ -29,7 +27,7 @@ has 'ua' => (
 has 'base_url' => (
     is => 'ro',
     lazy => 1,
-    default => sub { 'http://api.geocod.io/v1/' },
+    default => sub { 'http://api.geocod.io/v1.2/' },
 );
 
 
@@ -80,13 +78,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 WebService::Geocodio::Request - A request role for Geocod.io
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 ATTRIBUTES
 
@@ -122,7 +122,7 @@ Mark Allen <mrallen1@yahoo.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Mark Allen.
+This software is copyright (c) 2018 by Mark Allen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
